@@ -102,7 +102,7 @@ def censustable(src, year, table):
 	allvars = json.loads(allvars)['variables']
 	ret = OrderedDict()
 	for k in sorted(allvars.keys()):
-		if ((src != 'sf1' and '_'.join(k.split('_')[:-1]) == table)
+		if ((src != 'sf1' and k[:len(table)+1] == table+'_')
 			or (src == 'sf1' and k[:len(table)] == table)): # SF1 variables do not include underscores after table names
 			if 'predicateType' not in allvars[k]: allvars[k]['predicateType'] = ''
 			ret[k] = {'label': allvars[k]['label'], 'concept': allvars[k]['concept'], 'predicateType': allvars[k]['predicateType']}
